/**
 * IMPORTANT: Changes in this file MUST be duplicated in edge-react-gui!
 */
import * as React from 'react';
import { View } from 'react-native';
import { showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { MainButton } from '../themed/MainButton';
import { ModalMessage, ModalTitle } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
/**
 * A modal with a title, message, and buttons.
 * This is an alternative to the native `Alert` component.
 *
 * Child components appear between the message and the buttons,
 * but this feature is only meant for inserting extra message elements,
 * like images or custom text formatting.
 *
 * Build a custom modal component if you need form fields, check boxes,
 * or other interactive elements.
 */
export function ButtonsModal(props) {
    const { bridge, title, message, children, buttons, closeArrow = false, disableCancel = false, fullScreen = false, warning } = props;
    const theme = useTheme();
    const handleCancel = disableCancel
        ? () => { }
        : () => bridge.resolve(undefined);
    const containerStyle = {
        flex: fullScreen ? 1 : 0
    };
    const textStyle = {
        justifyContent: 'flex-start'
    };
    const buttonsStyle = {
        justifyContent: 'flex-end'
    };
    return (React.createElement(ThemedModal, { closeButton: closeArrow, warning: warning, bridge: bridge, paddingRem: 1, onCancel: handleCancel },
        React.createElement(View, { style: containerStyle },
            React.createElement(View, { style: textStyle },
                title != null ? React.createElement(ModalTitle, null, title) : null,
                message != null ? React.createElement(ModalMessage, null, message) : null,
                children)),
        React.createElement(View, { style: buttonsStyle }, Object.keys(buttons).map((key, i, arr) => {
            let defaultType;
            if (theme.preferPrimaryButton) {
                defaultType = i === 0 ? 'primary' : 'secondary';
            }
            else {
                defaultType = i === 0 && arr.length > 1 ? 'primary' : 'secondary';
            }
            const { type = defaultType, label, onPress } = buttons[key];
            const handlePress = () => {
                if (onPress == null) {
                    bridge.resolve(key);
                    return;
                }
                return onPress().then(result => {
                    if (result)
                        bridge.resolve(key);
                }, error => showError(error));
            };
            return (React.createElement(MainButton, { key: key, label: label, marginRem: 0.5, type: type, onPress: handlePress }));
        }))));
}
