import * as React from 'react';
import { Platform, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import IonIcon from 'react-native-vector-icons/Ionicons';
import { useHandler } from '../../hooks/useHandler';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
export function Alert(props) {
    const { children, marginRem, message, numberOfLines = 2, paddingRem, title, type, onPress } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 1), theme.rem));
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 1), theme.rem));
    const typeColor = type === 'warning'
        ? theme.warningText
        : type === 'error'
            ? theme.dangerText
            : theme.primaryText;
    const handlePress = useHandler(() => {
        var _a;
        if (onPress != null)
            (_a = onPress()) === null || _a === void 0 ? void 0 : _a.catch(err => showError(err));
    });
    const result = (React.createElement(View, { style: [styles.alert, margin, padding, { borderColor: typeColor }] },
        React.createElement(View, { style: styles.header },
            type !== 'error' ? null : (React.createElement(IonIcon, { color: typeColor, name: Platform.OS === 'ios'
                    ? 'ios-information-circle-outline'
                    : 'md-information-circle-outline', size: theme.rem(1.25), style: styles.icon })),
            React.createElement(EdgeText, { style: [styles.title, { color: typeColor }] }, title)),
        message == null ? null : (React.createElement(EdgeText, { style: [styles.message, { color: typeColor }], numberOfLines: numberOfLines }, message)),
        children));
    return onPress ? (React.createElement(TouchableOpacity, { onPress: handlePress }, result)) : (result);
}
const getStyles = cacheStyles((theme) => ({
    alert: {
        borderWidth: theme.cardBorder,
        borderRadius: theme.cardBorderRadius,
        alignSelf: 'stretch'
    },
    header: {
        flexDirection: 'row',
        alignItems: 'center'
    },
    title: {
        fontSize: theme.rem(0.75)
    },
    icon: {
        marginRight: theme.rem(0.5)
    },
    message: {
        fontSize: theme.rem(0.75)
    }
}));
